# -*- encoding: utf-8 -*-

import unittest
import os

import productmd.compose
from compose_utils.changelog import ComposeChangelog


def _get_compose_path(ident):
    base = os.path.dirname(__file__)
    pth = os.path.join(base, 'composes', ident)
    return pth


DUMMY_FIREFOX_SIZE = 5966 + 5934
OLD_DUMMY_FIREFOX_SIZE = 5878 + 5842
DUMMY_ELINKS_SIZE = 5850 + 5826 + 5818
DUMMY_TFTP_SIZE = 5842 + 5814 + 5806

DUMMY_FIREFOX = {
    'size': DUMMY_FIREFOX_SIZE,
    'name': 'Dummy-firefox',
    'old_nvr': 'Dummy-firefox-16.0.1-1',
    'old_rpms': ['Dummy-firefox'],
    'common_rpms': ['Dummy-firefox'],
    'rpms': ['Dummy-firefox'],
    'changelog': ['* Tue Mar 15 2016 Lubomír Sedlář <lubomir.sedlar@gmail.com> - 1:0.1.0-1\n- new version'],
    'added_rpms': [],
    'dropped_rpms': [],
    'nvr': 'Dummy-firefox-1:0.1.0-1',
    'summary': 'A dummy firefox package',
    'size_change': DUMMY_FIREFOX_SIZE - OLD_DUMMY_FIREFOX_SIZE,
}

DUMMY_ELINKS = {
    'size': DUMMY_ELINKS_SIZE,
    'name': 'dummy-elinks',
    'rpms': ['dummy-elinks'],
    'nvr': 'dummy-elinks-2.6-2',
    'summary': 'A dummy elinks package',
}

DUMMY_TFTP = {
    'size': DUMMY_TFTP_SIZE,
    'name': 'dummy-tftp',
    'rpms': ['dummy-tftp'],
    'nvr': 'dummy-tftp-5.2-6',
    'summary': 'A dummy tftp package',
}


class ChangelogTest(unittest.TestCase):

    def test_changelog(self):
        old_compose = productmd.compose.Compose(_get_compose_path('DP-1.0-20160315.t.0'))
        new_compose = productmd.compose.Compose(_get_compose_path('DP-1.0-20160315.t.1'))
        changelog = ComposeChangelog()

        data = changelog.get_changelog(old_compose, new_compose)
        self.assertEqual(data['old_compose'], 'DP-1.0-20160315.t.0')
        self.assertEqual(data['new_compose'], 'DP-1.0-20160315.t.1')
        self.assertItemsEqual(data['added_packages'], [DUMMY_ELINKS])
        self.assertItemsEqual(data['dropped_packages'], [DUMMY_TFTP])
        self.assertItemsEqual(data['upgraded_packages'], [DUMMY_FIREFOX])
        self.assertItemsEqual(data['downgraded_packages'], [])
        self.assertDictEqual(data['summary'], {
            'added_packages': 1,
            'added_packages_size': DUMMY_ELINKS_SIZE,
            'upgraded_packages': 1,
            'upgraded_packages_size': DUMMY_FIREFOX_SIZE,
            'upgraded_packages_size_change': DUMMY_FIREFOX_SIZE - OLD_DUMMY_FIREFOX_SIZE,
            'dropped_packages': 1,
            'dropped_packages_size': DUMMY_TFTP_SIZE,
            'downgraded_packages': 0,
            'downgraded_packages_size': 0,
            'downgraded_packages_size_change': 0,
        })
